@@ -77,7 +77,7 @@ lifeTab.survival <- function(object,times,newdata,stats,intervals=FALSE,percent=
   # {{{ percent
   if (!is.null(stats)){
     statsList <- lapply(stats,function(x){
-      if (percent==TRUE && length(grep(x[1],c("n.event","n.lost","n.risk"),val=FALSE))==0)
+      if (percent==TRUE && length(grep(x[1],c("n.event","n.lost","n.risk"),value=FALSE))==0)
         100*as.numeric(c(x[2],object[[x[1]]])[pindex+1])
       else
         as.numeric(c(x[2],object[[x[1]]])[pindex+1])
