@@ -31,7 +31,8 @@
     message("\nCluster-correlated data:\n\n cluster variable: ",x$cluster,"\n")
   
   message(#"Predictor space:\n\n",
-          switch(x$covariate.type,"No covariates",c("Discrete predictor variables: ",discrete.predictors),
+          switch(x$covariate.type,"No covariates",c("Discrete predictor variables: ",
+                                                    paste(discrete.predictors,collapse=", ")),
                  c("Continuous predictors: ",continuous.predictors),c("  Discrete predictor variables: ",discrete.predictors,"\nContinuous predictor variables: ",continuous.predictors)))
   if (match("Hist",all.names(x$formula),nomatch=FALSE))
     summary(x$model.response,verbose=TRUE)
